Citing this project in publications:

Cherab does not yet have a published overview paper, one is planned in the near future.
Until then you can cite "Carr, M., Meakins, A., Baciero, A., Bernert, M., Callarelli, A.,
Field, A., Giroud, C., Harrison, J., Hawkes, N., Henderson, S. and Lipschultz, B.,
Towards integrated data analysis of divertor diagnostics with ray-tracing. 44th EPS Conference
on Plasma Physics (2017), Belfast, Northern Ireland UK."